@@ -368,7 +368,7 @@ class AgentLifeCycle:
         object._agent_run_options["rosbridge"] = {
             "command": "roslaunch rosbridge_server rosbridge_websocket.launch", "network_mode": "host"}
         object._agent_run_options["test"] = {"command": "bash"}
-        object._agent_run_options["cgs_bagger_server"] = {"command": "roslaunch cognicept_rosbagger cognicept_rosbagger_server.launch", "volumes": {
+        object._agent_run_options["cgs_bagger_server"] = {"command": "rosrun cognicept_rosbagger bagger_action_server.py", "volumes": {
             args.config.config_path + "bags/": {"bind": "/root/.cognicept/bags", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["other"] = {
             "command": "", "network_mode": "host"}
