@@ -46,6 +46,8 @@ class Configuration:
         Checks and returns value of `COG_ENABLE_SSH_KEY_AUTH` as bool.
     cognicept_key_rotate:
         Rotates AWS temporary keys retriving them from Cognicept API.
+    init_config(args):
+        Initiates runtime.env file with values from Cognicept API
     """
     config_path = os.path.expanduser("~/.cognicept/")
     env_path = config_path + "runtime.env"
@@ -65,7 +67,12 @@ class Configuration:
 
         if ((not file.exists()) or (file.is_dir())):
             print("Configuration file `" + object.env_path + "` does not exist.")
-            return False
+            try:
+                with open(object.env_path, 'w') as f:
+                    pass
+            except:
+                print("Failed to initialize the robot: insufficient priviledges to create `/home/username/.cognicept/runtime.env file.")
+                return False
 
         #object.config = dotenv_values(dotenv_path=file.name) if sys.version_info.minor > 5 else dotenv_values(dotenv_path=find_dotenv(), verbose=True)
         object.config = dotenv_values(
@@ -402,3 +409,54 @@ class Configuration:
         object.save_config()
 
         return True
+
+    def get_cognicept_user_api_uri(object):
+        """
+        Checks and returns `COGNICEPT_API_URI` from configuration.
+
+                Returns:
+                    cognicept_api_uri (str): value of `COGNICEPT_API_URI`, defaults to "https://app.cognicept.systems/api/v1/"
+        """
+        if "COGNICEPT_API_URI" in object.config:
+            return object.config["COGNICEPT_API_URI"] 
+        else:
+            return "https://app.cognicept.systems/api/v1/"
+    def init_config(object, args):
+        """
+        Initiates runtime.env file with values from Cognicept API.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): True if succeeded
+        """
+        username = input('Username: ')
+        password = getpass.getpass()
+        api_uri = object.get_cognicept_user_api_uri()
+        try:
+            x = requests.post(api_uri + 'user/login', json={'username': username, 'password': password})
+            if 'access_token' not in x.json():
+                print('Failed to initialize the robot: Wrong credentials') 
+            else:
+                auth_key = x.json()["access_token"]
+
+                r = requests.get(api_uri + 'spinup/config/' + args.org_id + '/' + args.robot_id, headers={'Authorization': 'Bearer {}'.format(auth_key)})
+                j = r.json()
+                if j is not None:
+                    for key in j:
+                        object.config[key] = j[key]
+                    object.save_config()
+                    print("Successfully initialized configuration for the robot `" + args.robot_id + "`. To start agents run `cognicept start`")
+                    return True
+                else:
+                    print("Failed to initialize the robot: ID `" + args.robot_id + "` in organization `" + args.org_id + "` not found")
+                    return False
+        except requests.exceptions.Timeout:
+            print("Cognicept REST API error: time out.")
+            return False
+        except requests.exceptions.TooManyRedirects:
+            print("Cognicept REST API error: Wrong endpoint.")
+            return False
+        except Exception as e:
+            print("Cognicept REST API error" + str(e))
+            raise SystemExit()
\ No newline at end of file
