@@ -44,6 +44,8 @@ def main():
         'record', help='Manages rosbag recording')
     parser_push = subparsers.add_parser(
         'push', help='Pushes stuff to Cognicept cloud')
+    parser_init = subparsers.add_parser(
+        'init', help='Initiate runtime.env')
 
     local_cfg = Configuration()
     DEFAULT_PATH = "~/.cognicept/"
@@ -133,6 +135,16 @@ def main():
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_push.add_argument(
         '--bag', help='Pushes rosbag to the Cognicept cloud. By default it pushes the latest bag file recording. Set `BAG` to appropriate bag name in the `PATH` folder to upload a rosbag by name', type=str, const='latest', nargs='?')
+
+    
+    parser_init.set_defaults(func=local_cfg.init_config)
+    parser_init.add_argument(
+        '--path', default=DEFAULT_PATH)
+    parser_init.add_argument(
+        '--robot_id', help='Input the robot ID', required=True)
+    parser_init.add_argument(
+        '--org_id', help='Input the organisation ID', required=True)
+
     # Parse the arguments
     args = parser.parse_args()
 
@@ -148,4 +160,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
