@@ -22,25 +22,43 @@ from cogniceptshell.common import bcolors
 
 class ProgressPercentage(object):
     """
-    Track upload progress for chunks uploaded to S3
+    A class to track upload progress for chunks uploaded to S3
     ...
 
     Parameters
     ----------
-    TODO
+    _filename (str): Name of the file that is being uploaded
+    _size (float): Size of the file being uploaded
+    _seen_so_far (float): Size of the file already uploaded
+    _lock (threading.lock): Thread lock object for upload context
 
     Methods
     -------
-    TODO
+    __init__(filename):
+        Constructor for ProgressPercentage class that initializes all the parameters.
+    __call__(bytes_amount):
+        Main method to print progress percentage of file being uploaded.
     """
 
     def __init__(self, filename):
+        """
+        Constructor for ProgressPercentage class that initializes all the parameters.
+
+                Parameters:
+                        filename: Name of the file that is being uploaded
+        """
         self._filename = filename
         self._size = float(os.path.getsize(filename))
         self._seen_so_far = 0
         self._lock = threading.Lock()
 
     def __call__(self, bytes_amount):
+        """
+        Main method to print progress percentage of file being uploaded.
+
+                Parameters:
+                        bytes_amount: Size of the file already uploaded
+        """
         # To simplify, assume this is hooked up to a single filename
         with self._lock:
             self._seen_so_far += bytes_amount
@@ -54,23 +72,51 @@ class ProgressPercentage(object):
 
 class Pusher:
     """
-    TODO
+    A class to manage Cognicept's file pushes to the Cognicept cloud
     ...
 
     Parameters
     ----------
-    TODO
+    bucket_name (str): Name of the S3 bucket to upload to
 
     Methods
     -------
-    TODO
+    __init__():
+        Constructor for Pusher class that initializes all the parameters.
+    push(args):
+        Main entry point for the push operation.
+        Checks arguments and if valid, calls other methods to construct client and push the file.
+    construct_client(config_obj):
+        Creates an S3 client for temporary credentials fetched by key rotate operation.
+        Uses an instance of Configuration class.
+    push_bag(args):
+        Pushes bag to S3 and posts bag metadata to Cognicept cloud.
+    get_latest_bag(args):
+        Utility method to get the latest '.bag' file.
+    check_bag_exists(bag_file_path):
+        Utility method to check if specified bag file exists.
+    upload_s3(bag_file_path, config_obj):
+        Uploads specified bag file to configured S3 bucket.
+        Has built in retry mechanism  in case upload fails.
+    post_bag_metadata(bag_file_path):
+        Posts bag metadata to the Cognicept Cloud using Cognicept API.
     """
     def __init__(self):
+        """
+        Constructor for Pusher class that initializes all the parameters.
+
+                Parameters:
+                        bucket_name: Name of the S3 bucket to upload to
+        """
         self.bucket_name = 'cognicept-bagfiles'
 
     def push(self, args):
         """
-        Main push entry point
+        Main entry point for the push operation.
+        Checks arguments and if valid, calls other methods to construct client and push the file.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
         """
         if args.bag:
             # Construct client
@@ -84,25 +130,30 @@ class Pusher:
 
     def construct_client(self, config_obj):
         """
-        Utility function to create S3 client based on runtime.env credentials
-        """
-        local_cfg = config_obj.config
+        Creates an S3 client for temporary credentials fetched by key rotate operation.
 
-        if 'AWS_SESSION_TOKEN' in local_cfg:
+                Parameters:
+                        config_obj: An instance of Configuration class.
+        """
+        rotate_status = config_obj.cognicept_key_rotate(None)
+
+        if rotate_status:
+            local_cfg = config_obj.config
             self.s3_client = boto3.client(
                 's3', region_name='ap-southeast-1',
                 aws_access_key_id=local_cfg['AWS_ACCESS_KEY_ID'],
                 aws_secret_access_key=local_cfg['AWS_SECRET_ACCESS_KEY'],
                 aws_session_token=local_cfg['AWS_SESSION_TOKEN'])
         else:
-            self.s3_client = boto3.client(
-                's3', region_name='ap-southeast-1',
-                aws_access_key_id=local_cfg['AWS_ACCESS_KEY_ID'],
-                aws_secret_access_key=local_cfg['AWS_SECRET_ACCESS_KEY'])
+            raise(SystemExit)
 
     def push_bag(self, args):
         """
-        Push bag to S3 and bag metadata to Cognicept cloud
+        Pushes bag to S3 and posts bag metadata to Cognicept cloud.
+        If `args.bag` is set to `latest`, automatically finds the latest file to upload.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
         """
         upload_status = False
         if args.bag == 'latest':
@@ -137,7 +188,13 @@ class Pusher:
 
     def get_latest_bag(self, args):
         """
-        Get path of the latest bag file
+        Utility method to get the latest '.bag' file. 
+        If no file is found, exits program.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        latest_file (string): Full path of the latest bag file
         """
         bag_path = os.path.expanduser(args.path+"bags")
         bag_list = glob.glob(bag_path+"/*.bag")
@@ -151,7 +208,12 @@ class Pusher:
 
     def check_bag_exists(self, bag_file_path):
         """
-        Check if rosbag exists
+        Utility method to check if specified bag file exists.
+
+                Parameters:
+                        bag_file_path: Full path of the bag file to check
+                Returns:
+                        exist_status (boolean): True if specified bag file exists
         """
         if (os.path.exists(bag_file_path)):
             return True
@@ -160,7 +222,14 @@ class Pusher:
 
     def upload_s3(self, bag_file_path, config_obj):
         """
-        Upload rosbag to S3
+        Uploads specified bag file to configured S3 bucket.
+        Has built in retry mechanism  in case upload fails.
+
+                Parameters:
+                        bag_file_path: Full path of the bag file to upload
+                        config_obj: An instance of Configuration class
+                Returns:
+                        upload_status (boolean): True if bag file is uploaded successfully
         """
         # Multipart threaded approach for larger files
         config = TransferConfig(multipart_threshold=1024*25, max_concurrency=10,
@@ -186,7 +255,13 @@ class Pusher:
 
     def post_bag_metadata(self, args, bag_file_path):
         """
-        Post bag metadata to Cognicept cloud
+        Posts bag metadata to the Cognicept Cloud using Cognicept API.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                        bag_file_path: Full path of the bag file to upload
+                Returns:
+                        resp_status (boolean): True if metadata posted successfully
         """
         payload = {
             "robot_id": args.config.get_field("ROBOT_CODE"),
@@ -223,6 +298,7 @@ class Pusher:
                     bcolors.OKGREEN +
                     "Metadata posted to Cognicept Cloud." +
                     bcolors.ENDC)
+                return True
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return False
